#!/usr/bin/env python

from I3Tray import *
from I3Units import *
from math import *
from os.path import expandvars

import os

eve_num = 20
stream_num = 40
inPfile = "/misc/disk1/data/IceCube/MCdata/80strings/V01-09-06a/juliet/muon/slope-1/dataset_498/physics/juliet_mu_e1.000498.000000.i3.gz"
inGCSfile = "/misc/disk1/data/IceCube/MCdata/80strings/V01-09-06a/juliet/muon/slope-1/dataset_498/GCS/juliet_mu_e1.000498.80strGCS.i3.gz"
physfile  = "juliet.i3"
gcsfile   = "GCS.i3.gz"

if len(sys.argv) > 1:
	stream_num = sys.argv[1]
if len(sys.argv) > 2:
	physfile = sys.argv[2]
if len(sys.argv) > 3:
	gcsfile = sys.argv[3]

load("libc2j-icetray")
load("libicetray")
load("libdataclasses")
load('libdataio')
load("libDomTools")
load("libphys-services")
load("libsim-services")
load("libjuliet-interface")
load("libromeo")
load("libPSInterface")
load("libPSInterfaceFactory")
load("libDOMcalibrator")
load("libDOMsimulator")
load("libbrutus")
load("libsim-prod")


tray = I3Tray()

amageofile  = expandvars('$I3_WORK/phys-services/resources/amanda.geo')
icecubegeofile = expandvars('$I3_WORK/phys-services/resources/icecube.geo')
photonics = expandvars("$I3_WORK")

#
# Add services
#

tray.AddService("I3ReaderServiceFactory","reader")(
	("SkipKeys", ["CalibratedATWD","CalibratedFADC","I3JulietPrimaryParticle","IceTopRawData","InIceRawData","JulietParticle","MCHitSeriesMap","MCList","MCPMTResponseMap"]),
	#("Filename", inputfile)
        ("FilenameList",         [inGCSfile,inPfile])
	)

tray.AddService("I3JavaVMFactory", "java_vm")

tray.AddService("I3FileOMKey2MBIDFactory","omkey2mbid")(
	("Infile",photonics+"/phys-services/resources/doms.txt")
	)

tray.AddService("I3SPRNGRandomServiceFactory","random")(
        ("Seed",1),
        ("NStreams",10000),
        ("StreamNum",stream_num)
	)

tray.AddService("I3TweakDOMStatusService","tweakdom")(
	("OldServiceName","I3DetectorStatusService"),
	("TweakedServiceName","I3TweakDOMStatusService"),
	("NBinsATWD0InIce",128),
	("NBinsATWD1InIce",128),
	("NBinsATWD2InIce",128),
	("NBinsFADCInIce", 256)
	)


tray.AddService("I3GeometrySelectorServiceFactory","geo_selector")(
	("StringsToUse","1:80"),
	("GeoSelectorName","I3GeometrySelectorService")
	)

tray.AddService("I3PSInterfaceFactory","PSInterface")(
	("Interface","Photonics"),
	("TablesDirectory",photonics),
	("PhotonicsLevel1DriverFile","level1_table.list"),
	("PhotonicsLevel2DriverFile","level2_table.list")
	#("PhotonicsTableSelection",1) # cascade only
	)

#
# Add modules
#
tray.AddModule("I3Muxer", "multiplex")(
	("geometryservice","I3GeometryService"),
	#("eventservice","I3EventService"),
	#("calibrationservice","I3CalibrationService_80Str"),
	("detectorstatusservice","I3TweakDOMStatusService")
	)

  

tray.AddModule("I3JulietPrimaryParticleSource","fillprimary")(
     ("PrimaryFlavor",1),  #[e, mu, tau]=[0, 1, 2]
     ("PrimaryDoublet",0), #[neutrino, charged]=[0, 1]
     ("EnergyMin", 1.E5*I3Units.GeV),  #[GeV]
     ("EnergyMax", 1.E11*I3Units.GeV),
     ("DifferentialPowerLawIndex", 1.),
     ("InjectPositionX",0.*I3Units.m),
     ("InjectPositionY",0.*I3Units.m),
     ("InjectPositionZ",0.*I3Units.m),
     ("InjectRadius",880.*I3Units.m),
     ("NadirMin",0.*I3Units.deg),
     ("NadirMax",180.*I3Units.deg),
     ("AzimuthMin",0.*I3Units.deg),
     ("AzimuthMax",360.*I3Units.deg),
     ("NeutrinoInteractionWeight", 1)
     )

tray.AddModule("I3Juliet","propagate")(
     ("MaterialID",0),  # [ice, rock]=[0, 1]
     ("Flavor",1),      #[e, mu, tau]=[0, 1, 2]
                        #This should be same as the PrimaryFlavor
     ("DoChargedCurrent",1),
     ("DoNeutralCurrent",1),
     ("DoMuBremss",1),
     ("DoTauBremss",0),
     ("DoMuKnockOn",0),
     ("DoTauKnockOn",0),
     ("DoMu2ePairCreation",1),
     ("DoTau2ePairCreation",0),
     ("DoMu2muPairCreation",0),
     ("DoTau2muPairCreation",0),
     ("DoMu2tauPairCreation",0),
     ("DoTau2tauPairCreation",0),
     ("DoMuPhotoNuclear",1),
     ("DoTauPhotoNuclear",0),
     ("DoMuDecay",1),
     ("DoTauDecay",0),
     ("StartLocationID",2)  # 1: from the Earth surface
                            # 2: 880m away from the IceCube center
     )

tray.AddModule("I3HitConstructorModuleEHE","hit-constructor")(
	        ("MCListName","MCList"),
		("MaxMCHits", 500000)
)

tray.AddModule("I3RomeoInterfaceModule","romeo")(
	("SkipPhotoCathodeSimulator", False),
	("StorePMTPulses", False),                     # skip to store ceCubePMTPulse
	("RomeoOutputTimeResolution", 10.*I3Units.ns), # must same as MCHitBinSize of I3MCHitCompressor
	("RomeoPMTTimeResolution", 0.*I3Units.ns),     # anytime 0 when MCHits are compressed
	("RomeoVerboseLevel", 0)                       # verbose level, 0=silence to 5=trace
)

tray.AddModule("I3DOMsimulator","domsimulator")(
	("SimulatePedestalDroop", False)
)

tray.AddModule("I3DOMcalibrator","domcalibrator")(
	("CorrectPedestalDroop",False)
	)


tray.AddModule("I3RawDataEraser","eraser")(
	("eraseFADC", False) # false: keep calibratedFADCs, but delete rawFADCs
)

#tray.AddModule("I3Writer","writer")(
#        ("filename", physfile),
#	("skipkeys", ["DOMLaunch"]) # Skip writing the DOMLaunch which is the DOM data before
#	                            # the LC cleaning
#)
tray.AddModule("I3MCWriter","mcwriter")(
	("writegcs",False),
	("filename", physfile),
	("gcsfilename",gcsfile),
	("skipkeys", ["DOMLaunch"]) # Skip writing the DOMLaunch which is the DOM data before
	)

tray.AddModule("Dump","dump")
tray.AddModule("TrashCan", "the can")

tray.Execute()
tray.Finish()
